==> camel-k-model-v1-6.0.0-sources.jar: io/fabric8/camelk/v1/TraitSpecFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TraitSpecFluentImpl<A extends TraitSpecFluent<A>> extends BaseFluent<A> implements TraitSpecFluent<A>{
  public TraitSpecFluentImpl() {
  }
  public TraitSpecFluentImpl(TraitSpec instance) {
    this.withConfiguration(instance.getConfiguration()); 
  }
  private JsonNode configuration;
  public JsonNode getConfiguration() {
    return this.configuration;
  }
  public A withConfiguration(JsonNode configuration) {
    this.configuration=configuration; return (A) this;
  }
  public Boolean hasConfiguration() {
    return this.configuration != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TraitSpecFluentImpl that = (TraitSpecFluentImpl) o;
    if (configuration != null ? !configuration.equals(that.configuration) :that.configuration != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configuration,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configuration != null) { sb.append("configuration:"); sb.append(configuration); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/TraitSpecFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TraitSpecFluentImpl<A extends TraitSpecFluent<A>> extends BaseFluent<A> implements TraitSpecFluent<A>{
  public TraitSpecFluentImpl() {
  }
  public TraitSpecFluentImpl(TraitSpec instance) {
    if (instance != null) {
      this.withConfiguration(instance.getConfiguration());
    }
  }
  private JsonNode configuration;
  public JsonNode getConfiguration() {
    return this.configuration;
  }
  public A withConfiguration(JsonNode configuration) {
    this.configuration=configuration; return (A) this;
  }
  public Boolean hasConfiguration() {
    return this.configuration != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TraitSpecFluentImpl that = (TraitSpecFluentImpl) o;
    if (!java.util.Objects.equals(configuration, that.configuration)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configuration,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configuration != null) { sb.append("configuration:"); sb.append(configuration); }
    sb.append("}");
    return sb.toString();
  }
  
}
